log.handlers — PyZMQ v2.1.1dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- API »
- The PyZMQ API »

# log.handlers

## Module: `log.handlers`

Inheritance diagram for `zmq.log.handlers`:

pyzmq logging handlers.

This mainly defines the PUBHandler object for publishing logging messages over a zmq.PUB socket.

The PUBHandler can be used with the regular logging module, as in:

    >>> import logging
    >>> handler = PUBHandler('tcp://127.0.0.1:12345')
    >>> handler.root_topic = 'foo'
    >>> logger = logging.getLogger('foobar')
    >>> logger.addHandler(logging.DEBUG, handler)

After this point, all messages logged by `logger` will be published on the PUB socket.

Code adapted from StarCluster:

> http://github.com/jtriley/StarCluster/blob/master/starcluster/logger.py

### Authors

- Min RK

## Classes

### `PUBHandler`

class `zmq.log.handlers.` `PUBHandler`(interface_or_socket, context=None)

  Bases: `logging.Handler`

  A basic logging handler that emits log messages through a PUB socket.

  Takes a PUB socket already bound to interfaces or an interface to bind to.

  Example:

      sock = context.socket(zmq.PUB)
      sock.bind('inproc://log')
      handler = PUBHandler(sock)

  Or:

      handler = PUBHandler('inproc://loc')

  These are equivalent.

  Log messages handled by this handler are broadcast with ZMQ topics `this.root_topic` comes first, followed by the log level (DEBUG,INFO,etc.), followed by any additional subtopics specified in the message by: log.debug(“subtopic.subsub::the real message”)

  `acquire`()

    Acquire the I/O thread lock.

  `addFilter`(filter)

    Add the specified filter to this handler.

  `close`()

    Tidy up any resources used by the handler.

    This version does removes the handler from an internal list of handlers which is closed when shutdown() is called. Subclasses should ensure that this gets called from overridden close() methods.

  `createLock`()

    Acquire a thread lock for serializing access to the underlying I/O.

  `emit`(record)

    Emit a log message on my socket.

  `filter`(record)

    Determine if a record is loggable by consulting all the filters.

    The default is to allow the record to be logged; any filter can veto this and the record is then dropped. Returns a zero value if a record is to be dropped, else non-zero.

  `flush`()

    Ensure all logging output has been flushed.

    This version does nothing and is intended to be implemented by subclasses.

  `format`(record)

    Format a record.

  `handle`(record)

    Conditionally emit the specified logging record.

    Emission depends on filters which may have been added to the handler. Wrap the actual emission of the record with acquisition/release of the I/O thread lock. Returns whether the filter passed the record for emission.

  `handleError`(record)

    Handle errors which occur during an emit() call.

    This method should be called from handlers when an exception is encountered during an emit() call. If raiseExceptions is false, exceptions get silently ignored. This is what is mostly wanted for a logging system - most users will not care about errors in the logging system, they are more interested in application errors. You could, however, replace this with a custom handler if you wish. The record which was being processed is passed in to this method.

  `release`()

    Release the I/O thread lock.

  `removeFilter`(filter)

    Remove the specified filter from this handler.

  `setFormatter`(fmt)

    Set the formatter for this handler.

  `setLevel`(level)

    Set the logging level of this handler.

### `TopicLogger`

class `zmq.log.handlers.` `TopicLogger`(name, level=0)

  Bases: `logging.Logger`

  A simple wrapper that takes an additional argument to log methods.

  All the regular methods exist, but instead of one msg argument, two arguments: topic, msg are passed.

  That is:

      logger.debug('msg')

  Would become:

      logger.debug('topic.sub', 'msg')

  `addFilter`(filter)

    Add the specified filter to this handler.

  `addHandler`(hdlr)

    Add the specified handler to this logger.

  `callHandlers`(record)

    Pass a record to all relevant handlers.

    Loop through all handlers for this logger and its parents in the logger hierarchy. If no handler was found, output a one-off error message to sys.stderr. Stop searching up the hierarchy whenever a logger with the “propagate” attribute set to zero is found - that will be the last logger whose handlers are called.

  `critical`(level, topic, msg, *args, **kwargs)
  `debug`(level, topic, msg, *args, **kwargs)
  `error`(level, topic, msg, *args, **kwargs)
  `exception`(msg, *args)

    Convenience method for logging an ERROR with exception information.

  `fatal`(level, topic, msg, *args, **kwargs)
  `filter`(record)

    Determine if a record is loggable by consulting all the filters.

    The default is to allow the record to be logged; any filter can veto this and the record is then dropped. Returns a zero value if a record is to be dropped, else non-zero.

  `findCaller`()

    Find the stack frame of the caller so that we can note the source file name, line number and function name.

  `getEffectiveLevel`()

    Get the effective level for this logger.

    Loop through this logger and its parents in the logger hierarchy, looking for a non-zero logging level. Return the first one found.

  `handle`(record)

    Call the handlers for the specified record.

    This method is used for unpickled records received from a socket, as well as those created locally. Logger-level filtering is applied.

  `info`(msg, *args, **kwargs)

    Log ‘msg % args’ with severity ‘INFO’.

    To pass exception information, use the keyword argument exc_info with a true value, e.g.

    logger.info(“Houston, we have a %s”, “interesting problem”, exc_info=1)

  `isEnabledFor`(level)

    Is this logger enabled for level ‘level’?

  `log`(level, topic, msg, *args, **kwargs)

    Log ‘msg % args’ with level and topic.

    To pass exception information, use the keyword argument exc_info with a True value:

        logger.log(level, "zmq.fun", "We have a %s",
                "mysterious problem", exc_info=1)

  `makeRecord`(name, level, fn, lno, msg, args, exc_info, func=None, extra=None)

    A factory method which can be overridden in subclasses to create specialized LogRecords.

  `removeFilter`(filter)

    Remove the specified filter from this handler.

  `removeHandler`(hdlr)

    Remove the specified handler from this logger.

  `setLevel`(level)

    Set the logging level of this logger.

  `warn`(level, topic, msg, *args, **kwargs)
  `warning`(level, topic, msg, *args, **kwargs)

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- API »
- The PyZMQ API »